@@ -60,14 +60,14 @@
 #include <dialog/pimsettingexporterconfiguredialog.h>
 
 PimSettingExporterWindow::PimSettingExporterWindow(QWidget *parent)
-    : KXmlGuiWindow(parent),
-      mBackupAction(nullptr),
-      mRestoreAction(nullptr),
-      mSaveLogAction(nullptr),
-      mArchiveStructureInfo(nullptr),
-      mShowArchiveInformationsAction(nullptr),
-      mPimSettingsBackupRestoreUI(nullptr),
-      mTrayIcon(nullptr)
+    : KXmlGuiWindow(parent)
+    , mBackupAction(nullptr)
+    , mRestoreAction(nullptr)
+    , mSaveLogAction(nullptr)
+    , mArchiveStructureInfo(nullptr)
+    , mShowArchiveInformationsAction(nullptr)
+    , mPimSettingsBackupRestoreUI(nullptr)
+    , mTrayIcon(nullptr)
 {
     //Initialize filtermanager
     (void)MailCommon::FilterManager::instance();
@@ -88,6 +88,7 @@ PimSettingExporterWindow::PimSettingExporterWindow(QWidget *parent)
 
 PimSettingExporterWindow::~PimSettingExporterWindow()
 {
+    MailCommon::FilterManager::instance()->cleanup();
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup groupConfig = config->group(QStringLiteral("Recent File"));
     mRecentFilesAction->saveEntries(groupConfig);
@@ -156,8 +157,10 @@ void PimSettingExporterWindow::slotShowBackupFinishDialogInformation()
 void PimSettingExporterWindow::slotFullSyncFinished()
 {
     slotUpdateActions(false);
-    slotAddInfo(i18n("Full sync finished."));
+    const QString str = i18n("Full sync finished.");
+    slotAddInfo(str);
     mTrayIcon->setStatus(KStatusNotifierItem::Passive);
+    mTrayIcon->setToolTipSubTitle(str);
 }
 
 void PimSettingExporterWindow::slotFullSyncInstanceDone(const QString &identifier)
@@ -172,7 +175,8 @@ void PimSettingExporterWindow::slotFullSyncInstanceFailed(const QString &identif
 
 void PimSettingExporterWindow::showFinishInformation()
 {
-    KMessageBox::information(this, i18n("For restoring data, you must use \"pimsettingexporter\". Be careful it can overwrite existing settings, data."), i18n("Backup infos."), QStringLiteral("setProgressDialogLabelBackupInfos"));
+    KMessageBox::information(this, i18n("For restoring data, you must use \"pimsettingexporter\". Be careful it can overwrite existing settings, data."), i18n("Backup infos."),
+                             QStringLiteral("setProgressDialogLabelBackupInfos"));
     mTrayIcon->setStatus(KStatusNotifierItem::Passive);
 }
 
@@ -297,8 +301,8 @@ void PimSettingExporterWindow::backupData(const QString &filename, const QString
         if (currentFileName.isEmpty()) {
             QString recentDirClass;
             currentFileName = QFileDialog::getSaveFileName(this, i18n("Create backup"),
-                              KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///pimsettingexporter")), recentDirClass).toLocalFile(),
-                              i18n("Zip file (*.zip)"));
+                                                           KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///pimsettingexporter")), recentDirClass).toLocalFile(),
+                                                           i18n("Zip file (*.zip)"));
             if (currentFileName.isEmpty()) {
                 return;
             }
@@ -308,6 +312,7 @@ void PimSettingExporterWindow::backupData(const QString &filename, const QString
             mRecentFilesAction->addUrl(QUrl::fromLocalFile(currentFileName));
         }
         mTrayIcon->setStatus(KStatusNotifierItem::Active);
+        mTrayIcon->setToolTipSubTitle(i18n("Backup in progress..."));
         if (!mPimSettingsBackupRestoreUI->backupStart(currentFileName)) {
             qCDebug(PIMSETTINGEXPORTERGUI_LOG) << " backup Start failed";
         }
@@ -357,8 +362,8 @@ void PimSettingExporterWindow::loadData(const QString &filename, const QString &
     if (currentFileName.isEmpty()) {
         QString recentDirClass;
         currentFileName = QFileDialog::getOpenFileName(this, i18n("Restore backup"),
-                          KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///pimsettingexporter")), recentDirClass).toLocalFile(),
-                          i18n("Zip File (*.zip)"));
+                                                       KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///pimsettingexporter")), recentDirClass).toLocalFile(),
+                                                       i18n("Zip File (*.zip)"));
         if (currentFileName.isEmpty()) {
             return;
         }
@@ -390,6 +395,7 @@ void PimSettingExporterWindow::loadData(const QString &filename, const QString &
         delete dialog;
 
         mTrayIcon->setStatus(KStatusNotifierItem::Active);
+        mTrayIcon->setToolTipSubTitle(i18n("Restore in progress..."));
         if (!mPimSettingsBackupRestoreUI->restoreStart(currentFileName)) {
             qCDebug(PIMSETTINGEXPORTERGUI_LOG) << " PimSettingExporterWindow restore failed";
         }
